@@ -29,12 +29,19 @@ class PortalSession(
         Logs in current session to the Arpeggio portal. All subsequent requests will be
         authenticated with these credentials. Will try the `api_key` first if
         specified. If `api_key` is not present can use the same `email` and `password`
-        that is used to log in to the portal.
+        that is used to log in to the portal. If email is entered without as password
+        the user will be asked to enter their password. NOTE: we do not reccommend
+        saving your password in a script, either access it as an environment variable or
+        enter it interactively.
 
         Args:
             api_key (str): login key
             email (str): email used to login to the arpeggio portal
             password (str): password used to login to the arpeggio portal
+
+        Examples:
+            >>> p = PortalSession()
+            >>> p.login(email = user@domain.com)
         """
         if api_key is None:
             if email is not None and password is None:
