@@ -9,6 +9,10 @@ class ProjectsMixin(RequestCore):
         Lists projects accessible withthin the current portal session. Project access is
         limited by user id.
 
+        Examples:
+            >>> # p is a logged in portal session
+            >>> p.projects()
+
         Returns:
             DataFrame: table of project descriptions and ids
         """
@@ -29,5 +33,9 @@ class ProjectsMixin(RequestCore):
 
         Args:
             project_id (int): project id.
+
+        Examples:
+            >>> # p is a logged in portal session
+            >>> p.set_project(3)
         """
         self._post("project/session", {"project_id": project_id})
