@@ -97,6 +97,62 @@ class SamplesMixin(RequestCore):
         out.columns = [str(x["sample_id"]) for x in counts[1]]
         return out
 
+    def submitAnnotationCount(self, annotation_id, sample_ids):
+        """Submit an annotation count job
+
+        For a give annotation set and a given set of sample_ids, count
+        up the number of reads over those samples.
+
+        Args:
+            annotation_id (int): the id from the database
+            sample_ids (int, list): a list of sample_ids from the database
+        Returns:
+            None:
+                Just a print statement saying that it has been successfully submitted
+
+        """
+
+        response = self._post(
+            "sample/annotation",
+            {
+                "annotation_id": annotation_id,
+                "sample_ids": sample_ids,
+                "retrieve": False,
+            },
+            expect_data=False,
+        )["response"]
+        if response["notification"]:
+            print(response["notification"])
+        return response
+
+    def getAnnotationCount(self, annotation_id, sample_ids):
+        """Retrieve the annotation count data
+
+        For a give annotation set and a given set of sample_ids, retrieve
+        the underlying count data for each of those intervals across those samples.
+        Note that this will only return if all the samples within the get method
+        have been submitted and that job has successfully been run.
+
+        Args:
+            annotation_id (int): the id from the database
+            sample_ids (int, list): a list of sample_ids from the database
+        Returns:
+            None:
+                Just a print statement saying that it has been successfully submitted
+
+        """
+
+        data = self._post(
+            "sample/annotation",
+            {
+                "annotation_id": annotation_id,
+                "sample_ids": sample_ids,
+                "retrieve": True,
+            },
+            expect_data=True,
+        )["response"]["data"]
+        return data
+
     def gene_count(self, sample_ids):
         """Get gene TPMs
 
